KTrace

Struct KTrace 

pub struct KTrace { /* private fields */ }
A pure Rust implementation of KTrace.

Implementations

Source

impl KTrace

pub fn get_instance() -> &'static Self

Retrieve the global instance of KTrace.

pub unsafe fn reserve( &self, header: u64, ) -> Result<KTraceReservation<'_>, Status>

Reserves a slot of memory to write a record into.

Safety

This method MUST be invoked with interrupts disabled to enforce the single-writer invariant.

pub fn writes_enabled(&self) -> bool

Returns true if writes are currently enabled.

pub fn categories_bitmask(&self) -> u32

Returns the categories bitmask.

pub fn is_category_enabled(&self, category: &InternedCategory) -> bool

Returns true if the given category is enabled.